#
# spec file for package kpipewire
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _sover 5
# Full Plasma 5 version (e.g. 5.9.1)
%{!?_plasma5_bugfix: %global _plasma5_bugfix %{version}}
%bcond_without released
Name:           kpipewire
Version:        5.27.11
Release:        1.1
Summary:        PipeWire integration for KDE Plasma
License:        LGPL-2.0-only AND LGPL-3.0-only
Group:          Development/Libraries/KDE
URL:            https://www.kde.org
Source:         https://download.kde.org/stable/plasma/%{version}/kpipewire-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/plasma/%{version}/kpipewire-%{version}.tar.xz.sig
Source2:        plasma.keyring
%endif
BuildRequires:  extra-cmake-modules
BuildRequires:  libQt5Gui-private-headers-devel >= 5.15.0
BuildRequires:  libQt5PlatformHeaders-devel
BuildRequires:  pkgconfig
BuildRequires:  cmake(KF5CoreAddons) >= 5.98.0
BuildRequires:  cmake(KF5I18n)
BuildRequires:  cmake(KF5Wayland)
BuildRequires:  cmake(PlasmaWaylandProtocols)
BuildRequires:  cmake(Qt5Core)
BuildRequires:  cmake(Qt5DBus)
BuildRequires:  cmake(Qt5Gui)
BuildRequires:  cmake(Qt5Quick)
BuildRequires:  cmake(Qt5WaylandClient)
BuildRequires:  pkgconfig(epoxy)
BuildRequires:  pkgconfig(gbm)
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(libdrm)
BuildRequires:  pkgconfig(libpipewire-0.3)
BuildRequires:  pkgconfig(libswscale)
BuildRequires:  pkgconfig(wayland-client)

%description
KPipeWire provides PipeWire integration for the Plasma desktop and mobile shells.

%package -n libKPipeWire%{_sover}
Summary:        PipeWire integration for KDE Plasma - main library
%requires_eq    libQt5Gui

%description -n libKPipeWire%{_sover}
KPipeWire provides PipeWire integration for the Plasma desktop and mobile shells.
This package contains the main KPipeWire library.

%package -n libKPipeWireRecord%{_sover}
Summary:        PipeWire integration for KDE Plasma - recording support
%requires_eq    libQt5Gui

%description -n libKPipeWireRecord%{_sover}
KPipeWire provides PipeWire integration for the Plasma desktop and mobile shells.
This package contains the library needed for video and audio capture.

%package -n libKPipeWireDmaBuf%{_sover}
Summary:        PipeWire integration for KDE Plasma - DMA-BUF support
%requires_eq    libQt5Gui

%description -n libKPipeWireDmaBuf%{_sover}
KPipeWire provides PipeWire integration for the Plasma desktop and mobile shells.
This package provides a helper for downloading DMA-BUF textures for CPU processing.

%package imports
Summary:        QtQuick bindings for kpipewire
Requires:       libKPipeWire%{_sover} = %{version}
Requires:       libKPipeWireDmaBuf%{_sover} = %{version}
Requires:       libKPipeWireRecord%{_sover} = %{version}

%description imports
KPipeWire provides PipeWire integration for the Plasma desktop and mobile shells.
This package provides QtQuick bindings for the main KPipeWire libraries.

%package devel
Summary:        Development files for kpipewire
Group:          Development/Libraries/KDE
Requires:       %{name}-imports = %{version}
Requires:       libKPipeWire%{_sover} = %{version}
Requires:       libKPipeWireDmaBuf%{_sover} = %{version}
Requires:       libKPipeWireRecord%{_sover} = %{version}
Requires:       pkgconfig(epoxy)
Requires:       pkgconfig(libpipewire-0.3)

%description devel
KPipeWire provides PipeWire integration for the Plasma desktop and mobile shells.
This package provides the development files needed to build applications
which use KPipeWire.

%lang_package -n libKPipeWire%{_sover}

%prep
%autosetup -p1

%build
%cmake_kf5 -d build -- -DBUILD_TESTING=ON
%cmake_build

%install
%kf5_makeinstall -C build

%find_lang kpipewire%{_sover}

%check
%ctest

%post -n libKPipeWire%{_sover} -p /sbin/ldconfig
%postun -n libKPipeWire%{_sover} -p /sbin/ldconfig
%post -n libKPipeWireRecord%{_sover} -p /sbin/ldconfig
%postun -n libKPipeWireRecord%{_sover} -p /sbin/ldconfig
%post -n libKPipeWireDmaBuf%{_sover} -p /sbin/ldconfig
%postun -n libKPipeWireDmaBuf%{_sover} -p /sbin/ldconfig

%files -n libKPipeWire%{_sover}
%license LICENSES/*
%{_kf5_libdir}/libKPipeWire.so.%{_sover}
%{_kf5_libdir}/libKPipeWire.so.%{_sover}.*
%{_kf5_debugdir}/kpipewire.categories

%files -n libKPipeWireRecord%{_sover}
%{_kf5_libdir}/libKPipeWireRecord.so.%{_sover}
%{_kf5_libdir}/libKPipeWireRecord.so.%{_sover}.*
%{_kf5_debugdir}/kpipewirerecord.categories

%files -n libKPipeWireDmaBuf%{_sover}
%{_kf5_libdir}/libKPipeWireDmaBuf.so.%{_sover}
%{_kf5_libdir}/libKPipeWireDmaBuf.so.%{_sover}.*

%files imports
%dir %{_kf5_qmldir}/org
%dir %{_kf5_qmldir}/org/kde
%{_kf5_qmldir}/org/kde/pipewire

%files devel
%{_includedir}/KPipeWire/
%{_kf5_cmakedir}/KPipeWire/
%{_kf5_libdir}/libKPipeWire.so
%{_kf5_libdir}/libKPipeWireRecord.so
%{_kf5_libdir}/libKPipeWireDmaBuf.so

%files -n libKPipeWire%{_sover}-lang -f kpipewire%{_sover}.lang

%changelog
* Wed Mar  6 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.11:
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.11
- Changes since 5.27.10:
  * Port to new Gitlab CI format
* Wed Dec  6 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.10
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.10
- Changes since 5.27.9:
  * Adjust to KWayland moving to Plasma
* Tue Oct 24 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.9
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.9
- No code changes since 5.27.8
* Tue Sep 12 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.8
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.8
- No code changes since 5.27.7
* Tue Aug  1 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.7
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.7
- Changes since 5.27.6:
  * PipeWireSourceItem: proceed itemChange in QQuickItem
* Tue Jun 20 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.6
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.6
- No code changes since 5.27.5
* Tue May  9 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.5
- Changes since 5.27.4:
  * Item: hide the cursor when we start getting null positions
  * Item: Make sure we have a texture at all times
  * Do not process corrupt frames
  * Record: Do not crash when closing while recording (kde#467593)
  * Expose the stream size in PipewireSourceItem
* Tue Apr  4 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.4
- Changes since 5.27.3:
  * source: Handle BGRA buffers gracefully
  * record: Only create the sws_context when necessary
  * record: Use a good amount of threads as recommended by QThread
  * record: Make sure we process all the frames before leaving
  * record: Improve packet fetching
  * Use a different API call to make importing DmaBufs work on Nvidia (kde#448839)
  * options to disable motion estimation and in-loop filtering
  * record: Refactor thread distribution
  * record: Allocate SwsContext only when necessary
  * recording: Allocate frames when we render
  * recording: Extend the encoders API
* Tue Mar 14 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.3
- Changes since 5.27.2:
  * Guard m_producer
  * stream: better fallback for BGR formats when downloading into a QImage
  * stream: Fix support of SPA_VIDEO_FORMAT_RGB
  * recording: Drop unnecessary conditional
  * recording: use "good" deadline rather than quality that is deprecated upstream
  * recording: Make bitrate depend on the stream size
* Tue Feb 28 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.2
- Changes since 5.27.1:
  * PipewireSourceItem: Expose stream state
  * Finish the recording when the last frame has arrived
  * Export logging categories where they belong
  * sourcestream: Allocate the buffer outside together with the pods
* Tue Feb 21 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.1
- No code changes since 5.27.0
* Thu Feb  9 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.0
- Changes since 5.26.90:
  * record: Use vp8 instead of x264
  * Prefer x264
  * Allow to reset fd in `PipeWireSourceItem`
  * Record: Make sure we issue key frames and sequential pts
  * Record: Make sure the frames we encode are in an expected format
  * PipeWireRecord: Make sure we use the correct pixel formats
* Mon Jan 23 2023 Luca Beltrame <lbeltrame@kde.org>
- Require pipewire-devel for the -devel package
* Thu Jan 19 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.26.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.26.90
- Changes since 5.26.5:
  * HeadlessTest: Port ScreenCast to using fds properly too
  * Make sure unistd.h is included when close() is called
  * Make sure we don't leak file descriptors
  * It wasn't necessary to F_DUPFD_CLOEXEC the fd
  * PipeWireRecord: Allow providing which extension we are serving
  * ci: Require passing unit tests
  * Introduce KPipeWireDmaBuf
  * Remove duplicate headers between cpp/h files
  * Add autogenerated files to .gitignore
  * Record: Make sure we create the context properly
  * Record: Ensure we don't crash when the texture couldn't be produced
  * tests: Simplify code by using QScreens
  * Install po folder
  * recordme: Add a --help option
  * Validate cursor result of spa_buffer_find_meta_data
* Wed Jan  4 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.26.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.26.5
- No code changes since 5.26.4
* Tue Nov 29 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.26.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.26.4
- No code changes since 5.26.3
* Tue Nov  8 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.26.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.26.3
- No code changes since 5.26.2
* Wed Oct 26 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.26.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.26.2
- No code changes since 5.26.1
* Tue Oct 18 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.26.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.26.1
- No code changes since 5.26.0
* Thu Oct  6 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.26.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.26.0
- Changes since 5.25.90:
  * Install po folder
  * Validate cursor result of spa_buffer_find_meta_data
* Thu Sep 15 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.25.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.25.90
* Mon May 30 2022 Luca Beltrame <lbeltrame@kde.org>
- Initial package
